@@ -11,15 +11,20 @@ type Attribute interface {
 	Range() Range
 	Name() string
 	Contains(checkValue interface{}, equalityOptions ...EqualityOption) bool
+	NotContains(checkValue interface{}, equalityOptions ...EqualityOption) bool
 	StartsWith(prefix interface{}) bool
 	EndsWith(suffix interface{}) bool
 	Equals(checkValue interface{}, equalityOptions ...EqualityOption) bool
+	NotEqual(checkValue interface{}, equalityOptions ...EqualityOption) bool
 	RegexMatches(pattern interface{}) bool
 	IsAny(options ...interface{}) bool
+	IsNotAny(options ...interface{}) bool
 	IsNone(options ...interface{}) bool
 	IsTrue() bool
 	IsFalse() bool
 	IsEmpty() bool
+	IsNil() bool
+	IsNotNil() bool
 	MapValue(mapKey string) cty.Value
 	LessThan(checkValue interface{}) bool
 	LessThanOrEqualTo(checkValue interface{}) bool
