@@ -1,8 +1,7 @@
 package apigateway
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -75,12 +74,9 @@ resource "aws_api_gateway_stage" "good_example" {
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 
 			if resourceBlock.MissingChild("access_log_settings") {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' is missing access log settings block.", resourceBlock.FullName())),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' is missing access log settings block.", resourceBlock.FullName())
 			}
-
 		},
 	})
 }
