@@ -1,7 +1,7 @@
 package athena
 
+// generator-locked
 import (
-	"fmt"
 	"strings"
 
 	"github.com/aquasecurity/tfsec/pkg/result"
@@ -92,7 +92,6 @@ resource "aws_athena_workgroup" "good_example" {
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 
 			blockName := resourceBlock.FullName()
-
 			if strings.EqualFold(resourceBlock.TypeLabel(), "aws_athena_workgroup") {
 				if !resourceBlock.HasChild("configuration") {
 					return
@@ -105,10 +104,8 @@ resource "aws_athena_workgroup" "good_example" {
 			}
 
 			if resourceBlock.MissingChild("encryption_configuration") {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' missing encryption configuration block.", blockName)),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' missing encryption configuration block.", blockName)
 			}
 
 		},
