@@ -1,8 +1,7 @@
 package autoscaling
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -15,8 +14,6 @@ import (
 	"github.com/aquasecurity/tfsec/pkg/rule"
 
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/scanner"
-
-	"github.com/zclconf/go-cty/cty"
 )
 
 func init() {
@@ -60,18 +57,16 @@ resource "aws_launch_configuration" "good_example" {
 
 			for _, defaultEncryptionBlock := range context.GetResourcesByType("aws_ebs_encryption_by_default") {
 				enabledAttr := defaultEncryptionBlock.GetAttribute("enabled")
-				if enabledAttr == nil || (enabledAttr.Type() == cty.Bool && enabledAttr.Value().True()) {
+				if enabledAttr.IsTrue() {
 					encryptionByDefault = true
 				}
 			}
 
 			rootDeviceBlock := resourceBlock.GetBlock("root_block_device")
-			if rootDeviceBlock == nil && !encryptionByDefault {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' uses an unencrypted root EBS block device. Consider adding <blue>root_block_device{ encrypted = true }</blue>", resourceBlock.FullName())),
-				)
-			} else if rootDeviceBlock != nil {
+			if rootDeviceBlock.IsNil() && !encryptionByDefault {
+				set.AddResult().
+					WithDescription("Resource '%s' uses an unencrypted root EBS block device. Consider adding <blue>root_block_device{ encrypted = true }</blue>", resourceBlock.FullName())
+			} else if rootDeviceBlock.IsNotNil() {
 				checkDeviceEncryption(rootDeviceBlock, encryptionByDefault, set, resourceBlock)
 			}
 
@@ -79,23 +74,18 @@ resource "aws_launch_configuration" "good_example" {
 			for _, ebsDeviceBlock := range ebsDeviceBlocks {
 				checkDeviceEncryption(ebsDeviceBlock, encryptionByDefault, set, resourceBlock)
 			}
-
 		},
 	})
 }
 
 func checkDeviceEncryption(deviceBlock block.Block, encryptionByDefault bool, set result.Set, resourceBlock block.Block) {
 	encryptedAttr := deviceBlock.GetAttribute("encrypted")
-	if encryptedAttr == nil && !encryptionByDefault {
-		set.Add(
-			result.New(resourceBlock).
-				WithDescription(fmt.Sprintf("Resource '%s' uses an unencrypted EBS block device. Consider adding <blue>encrypted = true</blue>", resourceBlock.FullName())),
-		)
-	} else if encryptedAttr != nil && encryptedAttr.Type() == cty.Bool && encryptedAttr.Value().False() {
-		set.Add(
-			result.New(resourceBlock).
-				WithDescription(fmt.Sprintf("Resource '%s' uses an unencrypted root EBS block device.", resourceBlock.FullName())).
-				WithAttribute(encryptedAttr),
-		)
+	if encryptedAttr.IsNil() && !encryptionByDefault {
+		set.AddResult().
+			WithDescription("Resource '%s' uses an unencrypted EBS block device. Consider adding <blue>encrypted = true</blue>", resourceBlock.FullName())
+	} else if encryptedAttr.IsFalse() {
+		set.AddResult().
+			WithDescription("Resource '%s' uses an unencrypted root EBS block device.", resourceBlock.FullName()).
+			WithAttribute(encryptedAttr)
 	}
 }
