@@ -1,8 +1,7 @@
 package cloudtrail
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -73,20 +72,16 @@ resource "aws_cloudtrail" "good_example" {
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 
 			if resourceBlock.MissingChild("kms_key_id") {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' does not have a kms_key_id set.", resourceBlock.FullName())),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' does not have a kms_key_id set.", resourceBlock.FullName())
 				return
 			}
 
 			kmsKeyIdAttr := resourceBlock.GetAttribute("kms_key_id")
 			if kmsKeyIdAttr.IsEmpty() {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' has a kms_key_id but it is not set.", resourceBlock.FullName())).
-						WithAttribute(kmsKeyIdAttr),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' has a kms_key_id but it is not set.", resourceBlock.FullName()).
+					WithAttribute(kmsKeyIdAttr)
 			}
 
 		},
