@@ -1,8 +1,7 @@
 package cloudtrail
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -71,20 +70,16 @@ resource "aws_cloudtrail" "good_example" {
 		DefaultSeverity: severity.High,
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 			if resourceBlock.MissingChild("enable_log_file_validation") {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' does not enable log file validation.", resourceBlock.FullName())),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' does not enable log file validation.", resourceBlock.FullName())
 				return
 			}
 
 			logFileValidationAttr := resourceBlock.GetAttribute("enable_log_file_validation")
 			if logFileValidationAttr.IsFalse() {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' does not enable log file validation.", resourceBlock.FullName())).
-						WithAttribute(logFileValidationAttr),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' does not enable log file validation.", resourceBlock.FullName()).
+					WithAttribute(logFileValidationAttr)
 			}
 		},
 	})
