@@ -1,8 +1,7 @@
 package ecr
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -63,20 +62,16 @@ resource "aws_ecr_repository" "good_example" {
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 
 			imageTagMutabilityAttr := resourceBlock.GetAttribute("image_tag_mutability")
-			if imageTagMutabilityAttr == nil {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' is missing `image_tag_mutability` attribute - it is required to make ecr image tag immutable.", resourceBlock.FullName())),
-				)
+			if imageTagMutabilityAttr.IsNil() {
+				set.AddResult().
+					WithDescription("Resource '%s' is missing `image_tag_mutability` attribute - it is required to make ecr image tag immutable.", resourceBlock.FullName())
 				return
 			}
 
-			if !imageTagMutabilityAttr.Equals("IMMUTABLE") {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' has `image_tag_mutability` attribute  not set to `IMMUTABLE`", resourceBlock.FullName())).
-						WithAttribute(imageTagMutabilityAttr),
-				)
+			if imageTagMutabilityAttr.NotEqual("IMMUTABLE") {
+				set.AddResult().
+					WithDescription("Resource '%s' has `image_tag_mutability` attribute  not set to `IMMUTABLE`", resourceBlock.FullName()).
+					WithAttribute(imageTagMutabilityAttr)
 			}
 
 		},
