@@ -1,8 +1,7 @@
 package redshift
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -64,10 +63,8 @@ resource "aws_redshift_cluster" "good_example" {
 		DefaultSeverity: severity.High,
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 			if resourceBlock.MissingChild("cluster_subnet_group_name") {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' is being deployed outside of a VPC", resourceBlock.FullName())),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' is being deployed outside of a VPC", resourceBlock.FullName())
 			}
 		},
 	})
