@@ -1,8 +1,8 @@
 package compute
 
+// generator-locked
 import (
 	"encoding/base64"
-	"fmt"
 
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
@@ -63,22 +63,22 @@ EOF
 
 			if resourceBlock.TypeLabel() == "azurerm_virtual_machine" {
 				for _, str := range customDataAttr.ValueAsStrings() {
-					if checkResult := checkStringForSensitive(str, resourceBlock); checkResult != nil {
-						checkResult.
+					if checkStringForSensitive(str) {
+						set.AddResult().
+							WithDescription("Resource '%s' has custom_data with sensitive data.", resourceBlock.FullName()).
 							WithAttribute(customDataAttr)
-						set.Add(checkResult)
 					}
 				}
 			} else if customDataAttr.IsResolvable() && customDataAttr.IsString() {
-				encoded, err := base64.RawStdEncoding.DecodeString(customDataAttr.Value().AsString())
+				encoded, err := base64.StdEncoding.DecodeString(customDataAttr.Value().AsString())
 				if err != nil {
 					debug.Log("could not decode the base64 string in the terraform, trying with the string verbatim")
 					encoded = []byte(customDataAttr.Value().AsString())
 				}
-				if checkResult := checkStringForSensitive(string(encoded), resourceBlock); checkResult != nil {
-					checkResult.
+				if checkStringForSensitive(string(encoded)) {
+					set.AddResult().
+						WithDescription("Resource '%s' has custom_data with sensitive data.", resourceBlock.FullName()).
 						WithAttribute(customDataAttr)
-					set.Add(checkResult)
 				}
 
 			}
@@ -86,10 +86,7 @@ EOF
 	})
 }
 
-func checkStringForSensitive(stringToCheck string, resourceBlock block.Block) *result.Result {
-	if scanResult := squealer.NewStringScanner().Scan(stringToCheck); scanResult.TransgressionFound {
-		return result.New(resourceBlock).
-			WithDescription(fmt.Sprintf("Resource '%s' has custom_data with sensitive data.", resourceBlock.FullName()))
-	}
-	return nil
+func checkStringForSensitive(stringToCheck string) bool {
+	scanResult := squealer.NewStringScanner().Scan(stringToCheck)
+	return scanResult.TransgressionFound
 }
