@@ -1,7 +1,7 @@
 package network
 
+// generator-locked
 import (
-	"fmt"
 	"strings"
 
 	"github.com/aquasecurity/tfsec/pkg/result"
@@ -59,34 +59,26 @@ resource "azurerm_network_security_rule" "good_example" {
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 
 			directionAttr := resourceBlock.GetAttribute("direction")
-			if directionAttr == nil || directionAttr.Type() != cty.String || strings.ToUpper(directionAttr.Value().AsString()) != "OUTBOUND" {
+			if directionAttr.IsNil() || directionAttr.Type() != cty.String || strings.ToUpper(directionAttr.Value().AsString()) != "OUTBOUND" {
 				return
 			}
 
-			if prefixAttr := resourceBlock.GetAttribute("destination_address_prefix"); prefixAttr != nil && prefixAttr.Type() == cty.String {
+			if prefixAttr := resourceBlock.GetAttribute("destination_address_prefix"); prefixAttr.IsString() {
 				if cidr.IsOpen(prefixAttr) {
-					if accessAttr := resourceBlock.GetAttribute("access"); accessAttr != nil && strings.ToUpper(accessAttr.Value().AsString()) == "ALLOW" {
-						set.Add(
-							result.New(resourceBlock).
-								WithDescription(fmt.Sprintf(
-									"Resource '%s' defines a fully open %s network security group rule.",
-									resourceBlock.FullName(),
-									strings.ToLower(directionAttr.Value().AsString()),
-								)).
-								WithAttribute(prefixAttr),
-						)
+					if accessAttr := resourceBlock.GetAttribute("access"); accessAttr.IsNotNil() && strings.ToUpper(accessAttr.Value().AsString()) == "ALLOW" {
+						set.AddResult().
+							WithDescription("Resource '%s' defines a fully open %s network security group rule.", resourceBlock.FullName(), strings.ToLower(directionAttr.Value().AsString())).
+							WithAttribute(prefixAttr)
 					}
 				}
 			}
 
-			if prefixesAttr := resourceBlock.GetAttribute("destination_address_prefixes"); prefixesAttr != nil && prefixesAttr.Value().LengthInt() > 0 {
+			if prefixesAttr := resourceBlock.GetAttribute("destination_address_prefixes"); !prefixesAttr.IsEmpty() {
 				if cidr.IsOpen(prefixesAttr) {
-					if accessAttr := resourceBlock.GetAttribute("access"); accessAttr != nil && strings.ToUpper(accessAttr.Value().AsString()) == "ALLOW" {
-						set.Add(
-							result.New(resourceBlock).
-								WithDescription(fmt.Sprintf("Resource '%s' defines a fully open security group rule.", resourceBlock.FullName())).
-								WithAttribute(prefixesAttr),
-						)
+					if accessAttr := resourceBlock.GetAttribute("access"); accessAttr.IsNotNil() && strings.ToUpper(accessAttr.Value().AsString()) == "ALLOW" {
+						set.AddResult().
+							WithDescription("Resource '%s' defines a fully open security group rule.", resourceBlock.FullName()).
+							WithAttribute(prefixesAttr)
 					}
 				}
 			}
