@@ -1,7 +1,7 @@
 package network
 
+// generator-locked
 import (
-	"fmt"
 	"strings"
 
 	"github.com/aquasecurity/tfsec/pkg/result"
@@ -17,8 +17,6 @@ import (
 	"github.com/aquasecurity/tfsec/pkg/rule"
 
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/scanner"
-
-	"github.com/zclconf/go-cty/cty"
 )
 
 func init() {
@@ -59,34 +57,26 @@ resource "azurerm_network_security_rule" "good_example" {
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 
 			directionAttr := resourceBlock.GetAttribute("direction")
-			if directionAttr == nil || directionAttr.Type() != cty.String || strings.ToUpper(directionAttr.Value().AsString()) != "INBOUND" {
+			if directionAttr.NotEqual("INBOUND", block.IgnoreCase) {
 				return
 			}
 
-			if prefixAttr := resourceBlock.GetAttribute("source_address_prefix"); prefixAttr != nil && prefixAttr.Type() == cty.String {
+			if prefixAttr := resourceBlock.GetAttribute("source_address_prefix"); prefixAttr.IsString() {
 				if cidr.IsOpen(prefixAttr) {
-					if accessAttr := resourceBlock.GetAttribute("access"); accessAttr != nil && strings.ToUpper(accessAttr.Value().AsString()) == "ALLOW" {
-						set.Add(
-							result.New(resourceBlock).
-								WithDescription(fmt.Sprintf(
-									"Resource '%s' defines a fully open %s network security group rule.",
-									resourceBlock.FullName(),
-									strings.ToLower(directionAttr.Value().AsString()),
-								)).
-								WithAttribute(prefixAttr),
-						)
+					if accessAttr := resourceBlock.GetAttribute("access"); accessAttr.Equals("ALLOW", block.IgnoreCase) {
+						set.AddResult().
+							WithDescription("Resource '%s' defines a fully open %s network security group rule.", resourceBlock.FullName(), strings.ToLower(directionAttr.Value().AsString())).
+							WithAttribute(prefixAttr)
 					}
 				}
 			}
 
-			if prefixesAttr := resourceBlock.GetAttribute("source_address_prefixes"); prefixesAttr != nil && prefixesAttr.Value().LengthInt() > 0 {
+			if prefixesAttr := resourceBlock.GetAttribute("source_address_prefixes"); !prefixesAttr.IsEmpty() {
 				if cidr.IsOpen(prefixesAttr) {
-					if accessAttr := resourceBlock.GetAttribute("access"); accessAttr != nil && strings.ToUpper(accessAttr.Value().AsString()) == "ALLOW" {
-						set.Add(
-							result.New(resourceBlock).
-								WithDescription(fmt.Sprintf("Resource '%s' defines a fully open security group rule.", resourceBlock.FullName())).
-								WithAttribute(prefixesAttr),
-						)
+					if accessAttr := resourceBlock.GetAttribute("access"); accessAttr.Equals("ALLOW", block.IgnoreCase) {
+						set.AddResult().
+							WithDescription("Resource '%s' defines a fully open security group rule.", resourceBlock.FullName()).
+							WithAttribute(prefixesAttr)
 					}
 				}
 			}
