@@ -1,8 +1,7 @@
 package network
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -71,17 +70,15 @@ resource "azurerm_network_watcher_flow_log" "good_watcher" {
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 
 			if resourceBlock.MissingChild("retention_policy") {
-				set.Add(
-					result.New(resourceBlock).WithDescription(fmt.Sprintf("Resource '%s' is missing the required retention policy block", resourceBlock.FullName())),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' is missing the required retention policy block", resourceBlock.FullName())
 				return
 			}
 
 			retentionPolicyBlock := resourceBlock.GetBlock("retention_policy")
 			if retentionPolicyBlock.MissingChild("enabled") || retentionPolicyBlock.MissingChild("days") {
-				set.Add(
-					result.New(resourceBlock).WithDescription(fmt.Sprintf("Resource '%s' is missing the required attributes retention policy block", resourceBlock.FullName())),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' is missing the required attributes retention policy block", resourceBlock.FullName())
 				return
 			}
 
@@ -89,17 +86,15 @@ resource "azurerm_network_watcher_flow_log" "good_watcher" {
 			daysAttr := retentionPolicyBlock.GetAttribute("days")
 
 			if enabledAttr.IsFalse() {
-				set.Add(
-					result.New(resourceBlock).WithDescription(fmt.Sprintf("Resource '%s' has retention policy turned off", resourceBlock.FullName())).
-						WithAttribute(enabledAttr),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' has retention policy turned off", resourceBlock.FullName()).
+					WithAttribute(enabledAttr)
 			}
 
 			if daysAttr.LessThan(90) {
-				set.Add(
-					result.New(resourceBlock).WithDescription(fmt.Sprintf("Resource '%s' has retention policy period of less than 90 days", resourceBlock.FullName())).
-						WithAttribute(daysAttr),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' has retention policy period of less than 90 days", resourceBlock.FullName()).
+					WithAttribute(daysAttr)
 			}
 		},
 	})
