@@ -1,8 +1,7 @@
 package network
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -107,10 +106,8 @@ resource "azurerm_network_security_group" "example" {
 				if securityRule.HasChild("destination_port_range") && securityRule.GetAttribute("destination_port_range").Contains("22") {
 					if securityRule.HasChild("source_address_prefix") {
 						if securityRule.GetAttribute("source_address_prefix").IsAny("*", "0.0.0.0", "/0", "internet", "any") {
-							set.Add(
-								result.New(resourceBlock).
-									WithDescription(fmt.Sprintf("Resource '%s' has a .", resourceBlock.FullName())),
-							)
+							set.AddResult().
+								WithDescription("Resource '%s' has a .", resourceBlock.FullName()).WithBlock(securityRule)
 						}
 					}
 				}
