@@ -1,8 +1,7 @@
 package securitycenter
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -57,19 +56,17 @@ resource "azurerm_security_center_contact" "good_example" {
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 
 			if resourceBlock.MissingChild("alert_notifications") {
-				set.Add(
-					result.New(resourceBlock).WithDescription(fmt.Sprintf("Resource '%s' is missing the required setting for alert_notifications", resourceBlock.FullName())),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' is missing the required setting for alert_notifications", resourceBlock.FullName())
 
 				return
 			}
 
 			alertNotificationsAttr := resourceBlock.GetAttribute("alert_notifications")
 			if alertNotificationsAttr.IsFalse() {
-				set.Add(
-					result.New(resourceBlock).WithDescription(fmt.Sprintf("Resource '%s' has alert_notifications turned off", resourceBlock.FullName())).
-						WithAttribute(alertNotificationsAttr),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' has alert_notifications turned off", resourceBlock.FullName()).
+					WithAttribute(alertNotificationsAttr)
 			}
 
 		},
