@@ -1,8 +1,7 @@
 package compute
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/block"
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/cidr"
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/hclcontext"
@@ -70,11 +69,9 @@ resource "digitalocean_firewall" "good_example" {
 				}
 				sourceAddressesAttr := inboundRuleBlock.GetAttribute("source_addresses")
 				if cidr.IsOpen(sourceAddressesAttr) {
-					set.Add(
-						result.New(resourceBlock).
-							WithDescription(fmt.Sprintf("Resource '%s' defines a fully open inbound_rule.", resourceBlock.FullName())).
-							WithAttribute(sourceAddressesAttr),
-					)
+					set.AddResult().
+						WithDescription("Resource '%s' defines a fully open inbound_rule.", resourceBlock.FullName()).
+						WithAttribute(sourceAddressesAttr)
 				}
 			}
 		},
