@@ -1,8 +1,7 @@
 package loadbalancing
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/block"
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/hclcontext"
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/scanner"
@@ -80,10 +79,8 @@ resource "digitalocean_loadbalancer" "bad_example" {
 				}
 				entryPointAttr := rule.GetAttribute("entry_protocol")
 				if entryPointAttr.Equals("http", block.IgnoreCase) {
-					set.Add(result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' uses plain HTTP instead of HTTPS.", resourceBlock.FullName())).
-						WithAttribute(entryPointAttr),
-					)
+					set.AddResult().WithDescription("Resource '%s' uses plain HTTP instead of HTTPS.", resourceBlock.FullName()).
+						WithAttribute(entryPointAttr)
 				}
 			}
 		},
