@@ -1,8 +1,7 @@
 package spaces
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/block"
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/hclcontext"
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/scanner"
@@ -70,10 +69,8 @@ resource "digitalocean_spaces_bucket_object" "index" {
 			if resourceBlock.HasChild("acl") {
 				aclAttr := resourceBlock.GetAttribute("acl")
 				if aclAttr.Equals("public-read", block.IgnoreCase) {
-					set.Add(result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' has a publicly readable acl.", resourceBlock.FullName())).
-						WithAttribute(aclAttr),
-					)
+					set.AddResult().WithDescription("Resource '%s' has a publicly readable acl.", resourceBlock.FullName()).
+						WithAttribute(aclAttr)
 				}
 			}
 		},
