@@ -1,8 +1,7 @@
 package compute
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -52,13 +51,11 @@ resource "google_compute_firewall" "good_example" {
 		DefaultSeverity: severity.Critical,
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 
-			if sourceRanges := resourceBlock.GetAttribute("source_ranges"); sourceRanges != nil {
+			if sourceRanges := resourceBlock.GetAttribute("source_ranges"); sourceRanges.IsNotNil() {
 				if cidr.IsOpen(sourceRanges) {
-					set.Add(
-						result.New(resourceBlock).
-							WithDescription(fmt.Sprintf("Resource '%s' defines a fully open inbound firewall rule.", resourceBlock.FullName())).
-							WithAttribute(sourceRanges),
-					)
+					set.AddResult().
+						WithDescription("Resource '%s' defines a fully open inbound firewall rule.", resourceBlock.FullName()).
+						WithAttribute(sourceRanges)
 				}
 			}
 
