@@ -1,9 +1,7 @@
 package sql
 
+// generator-locked
 import (
-	"fmt"
-	"strings"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -47,7 +45,10 @@ resource "google_sql_database_instance" "db" {
 	}
 }
 			`},
-			Links: []string{"https://docs.microsoft.com/en-us/sql/database-engine/configure-windows/contained-database-authentication-server-configuration-option?view=sql-server-ver15"},
+			Links: []string{
+				"https://registry.terraform.io/providers/hashicorp/google/latest/docs/resources/sql_database_instance",
+				"https://docs.microsoft.com/en-us/sql/database-engine/configure-windows/contained-database-authentication-server-configuration-option?view=sql-server-ver15",
+			},
 		},
 		Provider:        provider.GoogleProvider,
 		RequiredTypes:   []string{"resource"},
@@ -56,45 +57,33 @@ resource "google_sql_database_instance" "db" {
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 
 			// we only need to check this for SQLSERVER, not mysql/postgres
-			dbVersionAttr := resourceBlock.GetAttribute("database_version")
-			if dbVersionAttr == nil || !dbVersionAttr.IsString() {
-				// default is postgres
-				return
-			}
-
-			if !strings.HasPrefix(dbVersionAttr.Value().AsString(), "SQLSERVER") {
+			if !resourceBlock.GetAttribute("database_version").StartsWith("SQLSERVER") {
 				return
 			}
 
 			settingsBlock := resourceBlock.GetBlock("settings")
-			if settingsBlock == nil {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' has contained database authentication enabled by default", resourceBlock.FullName())),
-				)
+			if settingsBlock.IsNil() {
+				set.AddResult().
+					WithDescription("Resource '%s' has contained database authentication enabled by default", resourceBlock.FullName())
 				return
 			}
 
 			for _, dbFlagBlock := range settingsBlock.GetBlocks("database_flags") {
-				if nameAttr := dbFlagBlock.GetAttribute("name"); nameAttr != nil && nameAttr.IsString() && nameAttr.Value().AsString() == "contained database authentication" {
-					if valueAttr := dbFlagBlock.GetAttribute("value"); valueAttr != nil && valueAttr.IsString() {
-						if valueAttr.Value().AsString() == "on" {
-							set.Add(
-								result.New(resourceBlock).
-									WithDescription(fmt.Sprintf("Resource '%s' has contained database authentication explicitly enabled", resourceBlock.FullName())),
-							)
-						}
-						// otherwise it's off, awesome
-						return
+				if dbFlagBlock.GetAttribute("name").Equals("contained database authentication") {
+					if valueAttr := dbFlagBlock.GetAttribute("value"); valueAttr.Equals("on") {
+						set.AddResult().
+							WithDescription("Resource '%s' has contained database authentication explicitly enabled", resourceBlock.FullName()).
+							WithAttribute(valueAttr)
 					}
+					// otherwise it's off, awesome
+					return
 				}
 			}
 
 			// we didn't find the flag so it must be on by default
-			set.Add(
-				result.New(resourceBlock).
-					WithDescription(fmt.Sprintf("Resource '%s' has contained database authentication enabled by default", resourceBlock.FullName())),
-			)
+			set.AddResult().
+				WithDescription("Resource '%s' has contained database authentication enabled by default", resourceBlock.FullName()).
+				WithBlock(settingsBlock)
 		},
 	})
 }
