@@ -1,8 +1,7 @@
 package sql
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -23,10 +22,10 @@ func init() {
 		Service:   "sql",
 		ShortCode: "no-public-access",
 		Documentation: rule.RuleDocumentation{
-			Summary: "Ensure that Cloud SQL Database Instances are not publicly exposed",
-			Explanation: `	`,
-			Impact:     "Public exposure of sensitive data",
-			Resolution: "Remove public access from database instances",
+			Summary:     "Ensure that Cloud SQL Database Instances are not publicly exposed",
+			Explanation: `Database instances should be configured so that they are not available over the public internet, but to internal compute resources which access them.`,
+			Impact:      "Public exposure of sensitive data",
+			Resolution:  "Remove public access from database instances",
 			BadExample: []string{`
 resource "google_sql_database_instance" "postgres" {
 	name             = "postgres-instance-a"
@@ -68,7 +67,10 @@ resource "google_sql_database_instance" "postgres" {
 	}
 }
 			`},
-			Links: []string{"https://www.cloudconformity.com/knowledge-base/gcp/CloudSQL/publicly-accessible-cloud-sql-instances.html#"},
+			Links: []string{
+				"https://registry.terraform.io/providers/hashicorp/google/latest/docs/resources/sql_database_instance",
+				"https://www.cloudconformity.com/knowledge-base/gcp/CloudSQL/publicly-accessible-cloud-sql-instances.html",
+			},
 		},
 		Provider:        provider.GoogleProvider,
 		RequiredTypes:   []string{"resource"},
@@ -76,42 +78,26 @@ resource "google_sql_database_instance" "postgres" {
 		DefaultSeverity: severity.High,
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 
-			// function contents here
-			settingsBlock := resourceBlock.GetBlock("settings")
-			if settingsBlock == nil {
+			ipConfigBlock := resourceBlock.GetBlock("settings").GetBlock("ip_configuration")
+			ipv4Attr := ipConfigBlock.GetAttribute("ipv4_enabled")
+			if ipv4Attr.IsNil() {
+				set.AddResult().
+					WithDescription("Resource '%s' has a public ipv4 address assigned by default", resourceBlock.FullName())
 				return
 			}
 
-			ipConfigBlock := settingsBlock.GetBlock("ip_configuration")
-			if ipConfigBlock == nil {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' has a public ipv4 address assigned by default", resourceBlock.FullName())),
-				)
-				return
-			}
-
-			if ipv4Attr := ipConfigBlock.GetAttribute("ipv4_enabled"); ipv4Attr == nil {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' has a public ipv4 address assigned by default", resourceBlock.FullName())),
-				)
-			} else if ipv4Attr.IsTrue() {
-				set.Add(
-					result.New(ipConfigBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' has a public ipv4 address explicitly assigned", resourceBlock.FullName())).
-						WithAttribute(ipv4Attr),
-				)
+			if ipv4Attr.IsTrue() {
+				set.AddResult().
+					WithDescription("Resource '%s' has a public ipv4 address explicitly assigned", resourceBlock.FullName()).
+					WithAttribute(ipv4Attr)
 				return
 			}
 
 			for _, authorizedNetworkBlock := range ipConfigBlock.GetBlocks("authorized_networks") {
-				if cidrAttr := authorizedNetworkBlock.GetAttribute("value"); cidrAttr != nil && cidrAttr.IsString() && cidr.IsOpen(cidrAttr) {
-					set.Add(
-						result.New(resourceBlock).
-							WithDescription(fmt.Sprintf("Resource '%s' authorizes access from the public internet", resourceBlock.FullName())).
-							WithAttribute(cidrAttr),
-					)
+				if cidrAttr := authorizedNetworkBlock.GetAttribute("value"); cidr.IsOpen(cidrAttr) {
+					set.AddResult().
+						WithDescription("Resource '%s' authorizes access from the public internet", resourceBlock.FullName()).
+						WithAttribute(cidrAttr)
 				}
 			}
 
